@@ -1,6 +1,6 @@
 /*
  *  GemPC410Utils.c
- *  $Id: GemPC410Utils.c,v 1.10 2004/07/03 21:42:45 rousseau Exp $
+ *  $Id: GemPC410Utils.c,v 1.11 2007-02-05 12:30:38 rousseau Exp $
  *  GemPC410 dedicated functions
  *
  *  Created by giraud on Sat Oct 20 2001.
@@ -21,7 +21,7 @@
 #include "GCdebug.h"
 #include "GCTransport.h"
 
-RESPONSECODE OpenGemPC410ByName(DWORD lun, LPTSTR dev_name)
+RESPONSECODE OpenGemPC410ByName(DWORD lun, LPSTR dev_name)
 {
 	UCHAR os_version[IFD_LEN_VERSION + 2];
 	DWORD length;
