@@ -19,7 +19,7 @@
  */
 
 /*
- * $Id: gbpserial.c,v 1.37 2005/06/17 10:38:47 rousseau Exp $
+ * $Id: gbpserial.c,v 1.38 2007-02-05 12:30:38 rousseau Exp $
  */
 
 #include <stdio.h>
@@ -345,7 +345,7 @@ RESPONSECODE ReadGBP(DWORD lun, PDWORD length, PUCHAR buffer)
  *				OpenGBP: open the port
  *
  *****************************************************************************/
-RESPONSECODE OpenGBP(DWORD lun, LPTSTR dev_name)
+RESPONSECODE OpenGBP(DWORD lun, LPSTR dev_name)
 {
 	struct termios current_termios;
 	int ospeed, i;
