@@ -1,6 +1,6 @@
 /*
  *  GemPC430Utils.c
- *  $Id: GemPC430Utils.c,v 1.18 2004/07/03 21:42:47 rousseau Exp $
+ *  $Id: GemPC430Utils.c,v 1.19 2007-02-05 12:30:39 rousseau Exp $
  *  GemPC430 dedicated functions
  *
  *  Created by giraud on Sat Oct 20 2001.
@@ -22,7 +22,7 @@
 #include "GCTransport.h"
 
 
-ifd_t OpenGemPC430ByName(DWORD lun, LPTSTR dev_name)
+ifd_t OpenGemPC430ByName(DWORD lun, LPSTR dev_name)
 {
 	UCHAR os_version[IFD_LEN_VERSION+2];
 	DWORD length;
