@@ -1,6 +1,6 @@
 /*
  * libusb_wrap.c
- * $Id: libusb_wrap.c,v 1.1.1.9 2006/02/09 13:36:46 rousseau Exp $
+ * $Id: libusb_wrap.c,v 1.1.1.10 2007-06-29 14:38:29 rousseau Exp $
  * USB access routines using the libusb library
  *
  * Created by Ludovic Rousseau on Sep 27 2002
@@ -73,7 +73,7 @@ typedef struct
 #error Edit this file and set the number of initialiser to PCSCLITE_MAX_READERS (default was 16 but it has changed)
 #endif
 static _usbDevice usbDevice[PCSCLITE_MAX_READERS] = {
-	[ 0 ... (PCSCLITE_MAX_READERS-1) ] = { NULL, NULL }
+	[ 0 ... (PCSCLITE_MAX_READERS-1) ] = { NULL, NULL, 0, 0, 0 }
 };
 
 /*****************************************************************************
@@ -81,7 +81,7 @@ static _usbDevice usbDevice[PCSCLITE_MAX_READERS] = {
  *					OpenUSB
  *
  ****************************************************************************/
-status_t OpenUSB(DWORD lun, LPTSTR device)
+status_t OpenUSB(DWORD lun, LPSTR device)
 {
 	static struct usb_bus *busses = NULL;
 	int id, id_number;
