@@ -1,6 +1,6 @@
 /*
  *  GCCmds.c
- *  $Id: GCCmds.c,v 1.36 2005/06/17 10:36:27 rousseau Exp $
+ *  $Id: GCCmds.c,v 1.39 2007-08-14 16:04:26 rousseau Exp $
  *  ifd-GemPC
  *
  *  Created by Jean-Luc Giraud on Sat Oct 20 2001.
@@ -335,8 +335,9 @@ ifd_t GCCmdGetOSVersion(const DWORD lun, PDWORD length, UCHAR buffer[])
 
 	/* clear the buffer to be sure it is \0 terminated */
 	memset(buffer, 0, *length);
-	/* length-1 to be sure their is room for the \0 */
-	rv = GCMakeCommand(lun, sizeof(cmd), cmd, length-1, buffer, &gc_rv);
+	/* decrease length by 1 to be sure their is room for the final \0 */
+	(*length)--;
+	rv = GCMakeCommand(lun, sizeof(cmd), cmd, length, buffer, &gc_rv);
 	GCGemCoreError(gc_rv, __FILE__, __LINE__, __FUNCTION__);
 
 	if (gc_rv != GCORE_OK)
@@ -446,6 +447,10 @@ ifd_t GCMakeCommand(const DWORD lun, const DWORD nLengthIn,
 	if (rv != STATUS_SUCCESS)
 		return IFD_COMMUNICATION_ERROR;
 
+	/* the reader response was empty */
+	if (0 == lengthout)
+		return IFD_COMMUNICATION_ERROR;
+
 	/* GemCore level error */
 	*response = buffer[GC_STATUS_OFFSET];
 
@@ -470,7 +475,6 @@ UCHAR GCGemCoreError(const UCHAR rv, const char *file, const int line, const cha
 	{
 		/* normal error code */
 		case GCORE_OK:
-			log_level = -1;
 			break;
 
 		case GCORE_UNKNOWN_CMD:
@@ -565,11 +569,11 @@ UCHAR GCGemCoreError(const UCHAR rv, const char *file, const int line, const cha
 			log_msg(PCSC_LOG_ERROR,
 				"%s:%d %s Unknown or undocumented error: 0x%02X",
 				file, line, function, rv);
-			log_level = -1;
 			break;
 	}
 
-	log_msg(log_level, "%s:%d %s %s", file, line, function, text);
+	if (text)
+		log_msg(log_level, "%s:%d %s %s", file, line, function, text);
 
 	return rv;
 } /* GCGemCoreError */
