@@ -13,7 +13,7 @@
 /            See http://www.linuxnet.com for more information.
 / License:   See file COPYING.BSD
 /
-/ $Id: ifdhandler.c,v 1.26 2006-02-09 13:29:35 rousseau Exp $
+/ $Id: ifdhandler.c,v 1.27 2007-02-05 12:30:41 rousseau Exp $
 /
 ******************************************************************/
 
@@ -46,7 +46,7 @@
 static GCoreDesc pgSlots[PCSCLITE_MAX_READERS];
 
 
-RESPONSECODE IFDHCreateChannelByName(DWORD Lun, LPTSTR lpcDevice)
+RESPONSECODE IFDHCreateChannelByName(DWORD Lun, LPSTR lpcDevice)
 {
 	DEBUG_INFO3("lun: %X, device: %s", Lun, lpcDevice);
 
